==> zither-1.1.15.tar.gz: zither_prj/apollon/menu2.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<HTML>";
echo "<HEAD>";
echo "<meta http-equiv='Content-Type' content='text/html; charset=EUC-JP'>";
echo "<TITLE>Zither server Administration tool 'Apollon'</TITLE>";

echo "<style type='text/css'>";
echo "<!--
a { text-decoration:none; }
a:hover { text-decoration:underline; }
a:hover { color:red; }

.example {
width: 100%;
max-width: 80px;
min-width: 60px;
}

-->";
echo "</style>";

echo "</HEAD>";





// Cname Bname List 
$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

//  ƻ֥å̾ꥹȺ
$bname_count = 0;
$result = pg_query($conn, "select distinct(bname) from userblock;");
if(!$result){
   print("banem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($bname_count < $num){
      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
      $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
      if(!$result1){
         print("bname , canem select , bud query\n");
         exit;
         }
      $num1 = pg_num_rows($result1);
      if($num1 > 0){
         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
         }
      $bname_count++;
      }
   }
else{
   print("NG ƻ֥å̵Ǥ \n");
   }
pg_free_result($result);
pg_free_result($result1);


$cname_count = 0;
$result=pg_query($conn,"select distinct(cname) from connection;");
if(!$result){
   print("canem select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($cname_count < $num){
      $xcname_data[$cname_count] = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
      $cname_count++;
      }
   }
pg_free_result($result);


$ip_count = 0;
$result=pg_query($conn,"select distinct(cip) from monitor;");
if(!$result){
   print("ip select , bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num > 0){
   while($ip_count < $num){
      $ip_data[$ip_count] = enco_rtrim(pg_fetch_Result($result, $ip_count, cip));
      $ip_count++;
      }
   }
pg_free_result($result);


pg_Close($conn);
// Cname Bname List 









echo "<center>";
print("<BODY Link='#FF8C00' Vlink='#FF8C00' Alink='#FF8C00'  bgcolor='$my_bgcolor' >\n");

// ƻ긡

echo "<h2 id='kanshi'></h2>";

echo "<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=125>";
echo "<tr>";
echo "<td align=center>";
echo "<font color='ffffff' size=2>";
echo "<b>";
echo "ƻ";
echo "</b>";
echo "</font>";
echo "</td>";
echo "</tr>";
echo "</table>";

echo "<a href='./monitor_manu.php?QUE_DATA=KENSAKU2' target='top'>ιܤΥޥ˥奢</a>";
echo "<br>";



echo "<FORM METHOD=GET ACTION='monitor.php' target='top'>";
echo "<TABLE border='0' bgcolor='FFEBCD' cellspacing='8' cellpadding='0' width=125>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻֹ";
echo "<INPUT type='text' NAME=UNO class='example' value=''>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=UNO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ륯饤̾";
echo "<select size=1 name=CNAME class='example'>";
echo "<option value=''>";
echo "ʤ";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CNAME_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻIP";
echo "<select size=1 name=CIP class='example'>";
echo "<option value=''>";
echo "ʤ";
for($select_count = 0; $select_count < $ip_count; $select_count++){
   echo "<option value=$ip_data[$select_count]>$ip_data[$select_count]";
   }
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CIP_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻIP(LIKE)";
echo "<INPUT type='text' NAME=CIP2 class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CIP2_CH>";
echo "</td>";
echo "</tr>";



echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ֥å̾";
echo "<select size=1 name=FREE4 class='example'>";
echo "<option value=''>";
echo "ʤ";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=FREE4_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ֥å(LIKE)";
echo "<INPUT type='text' NAME=FREE42 class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=FREE42_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ޥ or OID";
echo "<INPUT type='text' NAME=COM class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=COM_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "SECName or Port";
echo "<INPUT type='text' NAME=PORT class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PORT_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻξ";
echo "<INPUT type='text' NAME=CINFO class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CINFO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ°";
echo "<select size=1 name=MONITOR>";
echo "<option value=>NON";
echo "<option value=PORT>PORT";
echo "<option value=COMAND>COMAND";
echo "<option value=SNMP>SNMP";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=MONITOR_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ץȥ";
echo "<select size=1 name=PROTO>";
echo "<option value=>NON";
echo "<option value=SMTP>SMTP";
echo "<option value=URL>URL";
echo "<option value=DHW>DHW";
echo "<option value=TCP>TCP";
echo "<option value=UDP>UDP";
echo "<option value=ICMP>ICMP";
echo "<option value=SNTP>SNTP";
echo "<option value=HOST>HOST";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PROTO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ץ饤ƥ";
echo "<select size=1 name=PRINO>";
echo "<option value=>not";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=11>11";
echo "<option value=12>12";
echo "<option value=13>13";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PRINO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻON OFF";
echo "<select size=1 name=COME>";
echo "<option value=>not";
echo "<option value=ON>ON";
echo "<option value=OFF>OFF";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=COME_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ°";
echo "<select size=1 name=SIGN>";
echo "<option value=>not";
echo "<option value=0>";
echo "<option value=1>";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=SIGN_CH>";
echo "</td>";
echo "</tr>";

echo "<tr>";
echo "<td>";
echo "<font color='FF8C00' size=2>";
echo "åCSV";
echo "</font>";
echo "</td>";
echo "</tr>";

echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "<INPUT type='checkbox' NAME=CSV_CH>";
echo "<input type=submit value=''>";
echo "</font>";
echo "</td>";
echo "</tr>";


echo "</table>";
echo "</form>";

echo "<br>";
echo "</center>";

?>

</BODY>
</HTML>

==> zither-1.1.17.tar.gz: zither_prj/apollon/menu2.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<HTML>";
echo "<HEAD>";
echo "<meta http-equiv='Content-Type' content='text/html; charset=EUC-JP'>";
echo "<TITLE>Zither server Administration tool 'Apollon'</TITLE>";

echo "<style type='text/css'>";
echo "<!--
a { text-decoration:none; }
a:hover { text-decoration:underline; }
a:hover { color:red; }

.example {
width: 100%;
max-width: 80px;
min-width: 60px;
}

-->";
echo "</style>";

echo "</HEAD>";





// Cname Bname List 
$conn = db_connect();
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

//  ƻ֥å̾ꥹȺ
$bname_count = 0;
$result = db_query($conn, "select distinct(bname) from userblock;");
if(!$result){
   print("banem select , bud query\n");
   exit;
   }
$num = db_num_rows($result);
if($num > 0){
   while($bname_count < $num){
      $bname_data[$bname_count] = enco_rtrim(db_fetch_Result($result, $bname_count, bname));
      $result1=db_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
      if(!$result1){
         print("bname , canem select , bud query\n");
         exit;
         }
      $num1 = db_num_rows($result1);
      if($num1 > 0){
         $cname_data[$bname_count] = enco_rtrim(db_fetch_Result($result1, 0, cname));
         }
      $bname_count++;
      }
   }
else{
   print("NG ƻ֥å̵Ǥ \n");
   }
db_free_result($result);
db_free_result($result1);


$cname_count = 0;
$result=db_query($conn,"select distinct(cname) from connection;");
if(!$result){
   print("canem select , bud query\n");
   exit;
   }
$num = db_num_rows($result);
if($num > 0){
   while($cname_count < $num){
      $xcname_data[$cname_count] = enco_rtrim(db_fetch_Result($result, $cname_count, cname));
      $cname_count++;
      }
   }
db_free_result($result);


$ip_count = 0;
$result=db_query($conn,"select distinct(cip) from monitor;");
if(!$result){
   print("ip select , bud query\n");
   exit;
   }
$num = db_num_rows($result);
if($num > 0){
   while($ip_count < $num){
      $ip_data[$ip_count] = enco_rtrim(db_fetch_Result($result, $ip_count, cip));
      $ip_count++;
      }
   }
db_free_result($result);


db_Close($conn);
// Cname Bname List 









echo "<center>";
print("<BODY Link='#FF8C00' Vlink='#FF8C00' Alink='#FF8C00'  bgcolor='$my_bgcolor' >\n");

// ƻ긡

echo "<h2 id='kanshi'></h2>";

echo "<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=125>";
echo "<tr>";
echo "<td align=center>";
echo "<font color='ffffff' size=2>";
echo "<b>";
echo "ƻ";
echo "</b>";
echo "</font>";
echo "</td>";
echo "</tr>";
echo "</table>";

echo "<a href='./monitor_manu.php?QUE_DATA=KENSAKU2' target='top'>ιܤΥޥ˥奢</a>";
echo "<br>";



echo "<FORM METHOD=GET ACTION='monitor.php' target='top'>";
echo "<TABLE border='0' bgcolor='FFEBCD' cellspacing='8' cellpadding='0' width=125>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻֹ";
echo "<INPUT type='text' NAME=UNO class='example' value=''>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=UNO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ륯饤̾";
echo "<select size=1 name=CNAME class='example'>";
echo "<option value=''>";
echo "ʤ";
for($select_count = 0; $select_count < $cname_count; $select_count++){
   echo "<option value=$xcname_data[$select_count]>$xcname_data[$select_count]";
   }
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CNAME_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻIP";
echo "<select size=1 name=CIP class='example'>";
echo "<option value=''>";
echo "ʤ";
for($select_count = 0; $select_count < $ip_count; $select_count++){
   echo "<option value=$ip_data[$select_count]>$ip_data[$select_count]";
   }
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CIP_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻIP(LIKE)";
echo "<INPUT type='text' NAME=CIP2 class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CIP2_CH>";
echo "</td>";
echo "</tr>";



echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ֥å̾";
echo "<select size=1 name=FREE4 class='example'>";
echo "<option value=''>";
echo "ʤ";
for($select_count = 0; $select_count < $bname_count; $select_count++){
   echo "<option value=$bname_data[$select_count]>$bname_data[$select_count] ($cname_data[$select_count])";
   }
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=FREE4_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ֥å(LIKE)";
echo "<INPUT type='text' NAME=FREE42 class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=FREE42_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ޥ or OID";
echo "<INPUT type='text' NAME=COM class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=COM_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "SECName or Port";
echo "<INPUT type='text' NAME=PORT class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PORT_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻξ";
echo "<INPUT type='text' NAME=CINFO class='example' value='%'>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=CINFO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ°";
echo "<select size=1 name=MONITOR>";
echo "<option value=>NON";
echo "<option value=PORT>PORT";
echo "<option value=COMAND>COMAND";
echo "<option value=SNMP>SNMP";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=MONITOR_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ץȥ";
echo "<select size=1 name=PROTO>";
echo "<option value=>NON";
echo "<option value=SMTP>SMTP";
echo "<option value=URL>URL";
echo "<option value=DHW>DHW";
echo "<option value=TCP>TCP";
echo "<option value=UDP>UDP";
echo "<option value=ICMP>ICMP";
echo "<option value=SNTP>SNTP";
echo "<option value=HOST>HOST";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PROTO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ץ饤ƥ";
echo "<select size=1 name=PRINO>";
echo "<option value=>not";
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=11>11";
echo "<option value=12>12";
echo "<option value=13>13";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=PRINO_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻON OFF";
echo "<select size=1 name=COME>";
echo "<option value=>not";
echo "<option value=ON>ON";
echo "<option value=OFF>OFF";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=COME_CH>";
echo "</td>";
echo "</tr>";


echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "ƻ°";
echo "<select size=1 name=SIGN>";
echo "<option value=>not";
echo "<option value=0>";
echo "<option value=1>";
echo "</select>";
echo "</font>";
echo "</td>";
echo "<td>";
echo "<INPUT type='checkbox' NAME=SIGN_CH>";
echo "</td>";
echo "</tr>";

echo "<tr>";
echo "<td>";
echo "<font color='FF8C00' size=2>";
echo "åCSV";
echo "</font>";
echo "</td>";
echo "</tr>";

echo "<tr>";
echo "<td align=center>";
echo "<font color='FF8C00' size=2>";
echo "<INPUT type='checkbox' NAME=CSV_CH>";
echo "<input type=submit value=''>";
echo "</font>";
echo "</td>";
echo "</tr>";


echo "</table>";
echo "</form>";

echo "<br>";
echo "</center>";

?>

</BODY>
</HTML>
